try:
    from django.conf.urls import url
except:
    from django.urls import re_path as url

from . import views

urlpatterns = [
    url(r'^$', views.index, name='index'),
    url(r'^1337/$', views.details, name='1337'),
]



from collections import OrderedDict
from django.db import connections, OperationalError


def check(request):
    databases_info = []
    for db in connections:
        databases_info.append(get_connection_info(connections[db]))
    return databases_info


def get_connection_info(connection):
    connection_info = OrderedDict()

    engine = connection.settings_dict.get('ENGINE')

    connection_info['alias'] = connection.alias
    connection_info['name'] = connection.settings_dict.get('NAME')
    connection_info['engine'] = engine
    connection_info['version'] = get_database_version(connection, engine)
    connection_info['host'] = connection.settings_dict.get('HOST')
    connection_info['port'] = connection.settings_dict.get('PORT')
    return connection_info


def get_database_version(connection, engine):
    if connection.settings_dict['ENGINE'] == 'django.db.backends.dummy':
        return
    engines = {
        'django.db.backends.postgresql': 'SELECT version();',
        'django.db.backends.postgresql_psycopg2': 'SELECT version();',
        'django.db.backends.mysql': 'SELECT version();',
        'django.db.backends.sqlite3': 'select sqlite_version();',
        'django.db.backends.oracle': 'select * from v$version;',
        'django.contrib.gis.db.backends.mysql': 'SELECT version();',
        'django.contrib.gis.db.backends.postgis': 'SELECT version();',
        'django.contrib.gis.db.backends.spatialite': (
            'select sqlite_version();'
        ),
        'django.contrib.gis.db.backends.oracle': 'select * from v$version;',
    }
    query = engines[engine]
    return execute_sql(connection, query)


def execute_sql(connection, stmt):
    try:
        cursor = connection.cursor()
    except OperationalError as e:
        return {'error': str(e)}

    cursor.execute(stmt)
    result = cursor.fetchone()[0]
    return result



from pkg_resources import Requirement, WorkingSet

from django.conf import settings
from django.core.exceptions import ImproperlyConfigured


def check(request):
    package_name = settings.HEARTBEAT.get('package_name')
    if not package_name:
        raise ImproperlyConfigured(
            'Missing package_name key from heartbeat configuration')

    sys_path_distros = WorkingSet()
    package_req = Requirement.parse(package_name)

    distro = sys_path_distros.find(package_req)
    if not distro:
        return dict(error='no distribution found for {}'.format(package_name))

    return dict(name=distro.project_name, version=distro.version)



import sys


def check(request):
    return {
            'version': '{major}.{minor}.{micro}'.format(
                major=sys.version_info.major,
                minor=sys.version_info.minor,
                micro=sys.version_info.micro
            ),
            'info': sys.version,
            'executable': sys.executable,
            'platform': sys.platform
        }



import socket
import psutil
from datetime import datetime
from django.template.defaultfilters import filesizeformat, timesince


ips = []
for nic, addrs in psutil.net_if_addrs().items():
    for addr in addrs:
        if(socket.AF_INET is addr.family and "127.0.0.1" not in addr.address):
            ips.append(addr.address)


def check(request):
    return {
            'hostname': socket.gethostname(),
            'ips': ips,
            'cpus': psutil.cpu_count(),
            'uptime': timesince(datetime.fromtimestamp(psutil.boot_time())),
            'memory': {
                'total': filesizeformat(psutil.virtual_memory().total),
                'available': filesizeformat(psutil.virtual_memory().available),
                'used': filesizeformat(psutil.virtual_memory().used),
                'free': filesizeformat(psutil.virtual_memory().free),
                'percent': psutil.virtual_memory().percent
            },
            'swap': {
                'total': filesizeformat(psutil.swap_memory().total),
                'used': filesizeformat(psutil.swap_memory().used),
                'free': filesizeformat(psutil.swap_memory().free),
                'percent': psutil.swap_memory().percent
            }
        }



from django.conf import settings
from django.core.exceptions import ImproperlyConfigured


def default_checkers():
    heartbeat = getattr(settings, 'HEARTBEAT', {})
    if not heartbeat.get('checkers'):
        heartbeat['checkers'] = [
            'heartbeat.checkers.distribution_list',
            'heartbeat.checkers.debug_mode',
            'heartbeat.checkers.python',
            'heartbeat.checkers.host'
        ]
    prepare_redis(heartbeat)
    return heartbeat


def prepare_redis(heartbeat):
    if 'heartbeat.checkers.redis_status' in heartbeat['checkers']:
        redis = getattr(settings, 'CACHEOPS_REDIS', None)
        if redis is None:
            raise ImproperlyConfigured(
                'Missing CACHEOPS_REDIS in project settings')

HEARTBEAT = default_checkers()
